import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

from mns_common.db.MongodbUtil import MongodbUtil
from loguru import logger
from datetime import datetime
import mns_common.constant.extra_income_db_name as extra_income_db_name
import mns_common.component.cookie.cookie_info_service as cookie_info_service
import mns_common.api.em.real_time.east_money_stock_us_api as east_money_stock_us_api
import mns_common.api.em.real_time.east_money_debt_api as east_money_debt_api
import mns_common.api.em.real_time.east_money_etf_api as east_money_etf_api
import mns_common.api.em.real_time.east_money_stock_hk_api as east_money_stock_hk_api
import mns_common.api.em.real_time.east_money_stock_hk_gtt_api as east_money_stock_hk_gtt_api
import mns_common.api.em.real_time.east_money_stock_a_v2_api as east_money_stock_a_v2_api

mongodb_util = MongodbUtil('27017')


def sync_all_em_stock_info():
    logger.info("同步东方财富a,etf,kzz,us,hk,信息开始")
    # # 同步东方财富A股股票信息
    # sync_stock_info()
    # 同步东方财富A股可转债信息
    sync_kzz_info()
    # 同步东方财富A股ETF信息
    sync_etf_info()
    # 同步东方财富港股信息
    sync_hk_stock_info()
    # 同步东方财富港股通信息
    sync_hk_ggt_stock_info()
    # 同步东方财富美股信息
    sync_us_stock_info()

    logger.info("同步东方财富a,etf,kzz,us,hk,信息完成")


# 同步东方财富A股可转债信息
def sync_kzz_info():
    now_date = datetime.now()
    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    logger.error("同步东方财富可转债信息")
    try:
        em_kzz_info = east_money_debt_api.get_kzz_real_time_quotes(30, 6)
        em_kzz_info['_id'] = em_kzz_info['symbol']
        em_kzz_info['sync_time'] = str_now_date
        em_kzz_info = em_kzz_info.fillna(0)
        mongodb_util.save_mongo(em_kzz_info, extra_income_db_name.EM_KZZ_INFO)
    except BaseException as e:
        logger.error("同步东方财富可转债信息异常:{}", e)


# 同步东方财富A股ETF信息
def sync_etf_info():
    now_date = datetime.now()
    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    logger.error("同步东方财富ETF信息")
    try:
        em_etf_info = east_money_etf_api.get_etf_real_time_quotes(30, 6)
        em_etf_info['_id'] = em_etf_info['symbol']
        em_etf_info['sync_time'] = str_now_date
        em_etf_info = em_etf_info.fillna(0)
        mongodb_util.save_mongo(em_etf_info, extra_income_db_name.EM_ETF_INFO)
    except BaseException as e:
        logger.error("同步东方财富ETF信息异常:{}", e)


# 同步东方财富A股股票信息
def sync_stock_info():
    now_date = datetime.now()
    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    logger.error("同步东方财富股票信息")
    try:
        em_stock_info = east_money_stock_a_v2_api.get_stock_real_time_quotes(60)
        em_stock_info['_id'] = em_stock_info['symbol']
        em_stock_info['sync_time'] = str_now_date
        em_stock_info = em_stock_info.fillna(0)
        mongodb_util.save_mongo(em_stock_info, extra_income_db_name.EM_A_STOCK_INFO)
    except BaseException as e:
        logger.error("同步东方财富ETF信息异常:{}", e)


# 同步东方财富港股信息
def sync_hk_stock_info():
    now_date = datetime.now()
    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    logger.error("同步东方财富港股信息")

    em_cookie = cookie_info_service.get_em_cookie()

    try:
        em_hk_info = east_money_stock_hk_api.get_hk_real_time_quotes(30, em_cookie)
        em_hk_info['_id'] = em_hk_info['symbol']
        em_hk_info['sync_time'] = str_now_date
        em_hk_info = em_hk_info.fillna(0)
        mongodb_util.save_mongo(em_hk_info, extra_income_db_name.EM_HK_STOCK_INFO)
    except BaseException as e:
        logger.error("同步东方财富ETF信息异常:{}", e)


# 同步东方财富港股通信息
def sync_hk_ggt_stock_info():
    now_date = datetime.now()
    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    logger.error("同步东方财富港股信息")
    em_cookie = cookie_info_service.get_em_cookie()

    try:
        em_hk_gtt_info = east_money_stock_hk_gtt_api.get_ggt_real_time_quotes(em_cookie, 30, 6)
        em_hk_gtt_info['_id'] = em_hk_gtt_info['symbol']
        em_hk_gtt_info['sync_time'] = str_now_date
        em_hk_gtt_info = em_hk_gtt_info.fillna(0)
        mongodb_util.save_mongo(em_hk_gtt_info, extra_income_db_name.EM_HK_GGT_STOCK_INFO)
    except BaseException as e:
        logger.error("同步东方财富ETF信息异常:{}", e)


# 同步东方财富美股信息 todo 增加稳定接口
def sync_us_stock_info():
    now_date = datetime.now()
    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    logger.error("同步东方财富美股信息")
    em_cookie = cookie_info_service.get_em_cookie()
    us_stock_info = east_money_stock_us_api.get_us_real_time_quotes(30, em_cookie)
    us_stock_info['_id'] = us_stock_info['symbol']
    us_stock_info['sync_time'] = str_now_date

    us_stock_info = us_stock_info.fillna(0)
    mongodb_util.save_mongo(us_stock_info, extra_income_db_name.US_STOCK_INFO_EM)


if __name__ == '__main__':
    sync_all_em_stock_info()
    # em_cookie = cookie_info_service.get_em_cookie()
    # em_us_stock_info = east_money_stock_us_api.get_us_stock_real_time_quotes(em_cookie, None)
    # em_us_stock_info['_id'] = em_us_stock_info['symbol']
    # mongodb_util.save_mongo(em_us_stock_info, db_name_constant.EM_US_STOCK_INFO)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil
from loguru import logger

mongodb_util_27017 = MongodbUtil('27017')
mongodb_util_27019 = MongodbUtil('27019')


def update_col_data():
    query = {"$and": [{'trade_date': {'$lte': '2024-05-23'}},
                      {'trade_date': {'$gte': '2022-07-02'}}]}
    trade_date_list_df = mongodb_util_27017.find_query_data('trade_date_list', query)
    trade_date_list_df = trade_date_list_df.sort_values(by=['trade_date'], ascending=True)
    for trade_one in trade_date_list_df.itertuples():
        col_name = 'realtime_quotes_now_' + trade_one.trade_date
        new_values = {'$unset': {
            'classification': '',
            'medium_order_net_inflow': '',
            'small_order_net_inflow': '',
            'str_day': '',
            'list_date': '',
            'amount_level': '',
            'name': '', 'industry': '', 'concept': ''}}

        mongodb_util_27019.update_many({}, new_values, col_name)
        logger.info("完成集合数据更新:{}", col_name)


if __name__ == '__main__':
    update_col_data()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant
from loguru import logger
import mns_common.component.company.company_common_service_api as company_common_service_api

mongodb_util = MongodbUtil('27017')
import pandas as pd


# 开盘啦
def update_kpl_concept_info():
    query = {}
    kpl_best_choose_index_df = mongodb_util.find_query_data(db_name_constant.KPL_BEST_CHOOSE_INDEX, query)
    for kpl_concept_one in kpl_best_choose_index_df.itertuples():
        try:
            query_detail = {"plate_code": kpl_concept_one.plate_code}
            kpl_best_choose_index_detail_df = mongodb_util.find_query_data(
                db_name_constant.KPL_BEST_CHOOSE_INDEX_DETAIL,
                query_detail)
            concept_count = kpl_best_choose_index_detail_df.shape[0]
            kpl_best_choose_index_one_df = kpl_best_choose_index_df.loc[
                kpl_best_choose_index_df['plate_code'] == kpl_concept_one.plate_code]
            kpl_best_choose_index_one_df['concept_count'] = concept_count

            kpl_best_choose_index_detail_df = kpl_best_choose_index_detail_df.reset_index(drop=True)

            if 'industry' in kpl_best_choose_index_detail_df.columns:
                del kpl_best_choose_index_detail_df['industry']

            company_info_df = company_common_service_api.get_company_info_industry()
            company_info_df = company_info_df[['_id', 'industry']]
            company_info_df = company_info_df.loc[
                company_info_df['_id'].isin(list(kpl_best_choose_index_detail_df['symbol']))]
            company_info_df = company_info_df.set_index(['_id'], drop=True)

            kpl_best_choose_index_detail_df = kpl_best_choose_index_detail_df.set_index(['symbol'], drop=False)
            kpl_best_choose_index_detail_df = pd.merge(kpl_best_choose_index_detail_df, company_info_df,
                                                       how='outer',
                                                       left_index=True, right_index=True)
            kpl_best_choose_index_detail_df.dropna(subset=['industry'], axis=0, inplace=True)

            grouped = kpl_best_choose_index_detail_df.groupby('industry')
            result_list = grouped.size()
            ths_concept_group = pd.DataFrame(result_list, columns=['number'])
            ths_concept_group['industry'] = ths_concept_group.index
            ths_concept_group = ths_concept_group.sort_values(by=['number'], ascending=False)
            if ths_concept_group.shape[0] >= 2:
                first_relevance_industry = list(ths_concept_group.iloc[0:1]['industry'])[0]
                first_relevance_industry_number = list(ths_concept_group.iloc[0:1]['number'])[0]
                second_relevance_industry = list(ths_concept_group.iloc[1:2]['industry'])[0]
                second_relevance_industry_number = list(ths_concept_group.iloc[1:2]['number'])[0]
            else:
                first_relevance_industry = list(ths_concept_group.iloc[0:1]['industry'])[0]
                first_relevance_industry_number = list(ths_concept_group.iloc[0:1]['number'])[0]
                second_relevance_industry = '无'
                second_relevance_industry_number = 0
            kpl_best_choose_index_one_df['first_relevance_industry'] = first_relevance_industry
            kpl_best_choose_index_one_df['second_relevance_industry'] = second_relevance_industry
            kpl_best_choose_index_one_df['first_relevance_industry_number'] = first_relevance_industry_number
            kpl_best_choose_index_one_df['second_relevance_industry_number'] = second_relevance_industry_number

            kpl_best_choose_index_detail_df['first_relevance_industry'] = first_relevance_industry
            kpl_best_choose_index_detail_df['second_relevance_industry'] = second_relevance_industry

            mongodb_util.save_mongo(kpl_best_choose_index_one_df, db_name_constant.KPL_BEST_CHOOSE_INDEX)
            mongodb_util.save_mongo(kpl_best_choose_index_detail_df, db_name_constant.KPL_BEST_CHOOSE_INDEX_DETAIL)

        except Exception as e:
            logger.error("更新开盘啦概念异常:{},{}", e, kpl_concept_one.plate_name)


if __name__ == '__main__':
    update_kpl_concept_info()
